library(binom) 

listenerTargets =
    list(
        'L12'= 3,
        'L13'= 3,
        'L14'= 1,
        'L15'= 2,
        'L16'= 3,
        'L17'= c(1,3),
        'L18'= 2,
        'L19'= 2,
        'L20'= 2,
        'L21'= 3,
        'L22'= 1)

speakerTargets =
    list(
        'S1'= 'G',
        'S2'= 'M',
        'S3'= 'G',
        'S4'= 'G',
        'S5'= 'H',
        'S6'= 'H',
        'S7'= 'M',
        'S8'= 'H',
        'S9'= 'G',
        'S10'= 'M',
        'S11'= 'G'
        )

speakerSuppMap = list('M'=1, 'H'=2, 'G'=3, 'Other'=4)

speakerTargets = lapply(speakerTargets, function(x){speakerSuppMap[[x]]})

ItemPlot = function(d, colname, cats, vec, targets) {
    vals = xtabs(~ d[, colname]) 
    for (i in names(vals)) {
        vec[[i]] = vals[[i]]
    }
    vec = as.numeric(vec)    
    vec = rev(vec)
    cats = rev(cats)
    lowerci = binom.confint(vec, sum(vec), method='exact')[, 5] * sum(vec)
    upperci = binom.confint(vec, sum(vec), method='exact')[, 6] * sum(vec)
    par(mar=c(0,9,0,0))
    b = barplot(vec, names.arg=cats, horiz=T, las=1, cex.names=2, axes=F, xlim=c(0, 55), col='white')    
    target = targets[[colname]]
    target.x = 0
    target.y = rev(b)[target]
    text(target.x, target.y, 'Target', pos=4, cex=2)
    segments(lowerci, b, x1=upperci, lwd=2.5)
    text(upperci, b, vec, adj=-0.5, cex=2)
}

SpeakerPlot = function(d, colname) {
    cats = c('mustache', 'hat', 'glasses', 'Other')    
    vec = list('M'=0, 'H'=0, 'G'=0, '-'=0)
    ItemPlot(d, colname, cats, vec, speakerTargets)    
}

ListenerPlot = function(d, colname) {
    cats = c('R1', 'R2', 'R3', 'Other')
    vec = list('1'=0, '2'=0, '3'=0, '-'=0)
    ItemPlot(d, colname, cats, vec, listenerTargets)    
}

ListenerAll = function() {
    PlotAll('results-listener-coded.csv', colprefix='L', indices=12:22)
}

SpeakerAll = function() {
    PlotAll('results-speaker-coded.csv', colprefix='S', indices=1:11, PlotFunc=SpeakerPlot)
}

PlotAll = function(filename, colprefix='L', indices=12:22, PlotFunc=ListenerPlot) {
    outputdir = 'img-analysis'
    d = read.csv(filename)
    for (i in indices) {
        colname = paste(colprefix, i, sep='')
        pdf(paste(outputdir, '/', colname, '.pdf', sep=''), width=6, height=4)
        PlotFunc(d, colname)
        dev.off()
    }
}

ListenerAll()

SpeakerAll()
